@@ -40,6 +40,16 @@ def train(sequentions, epochs=100):
 
 
 def predict(x_input, model, predicts=7):
+    """Function that creates predictions from trained model and input data.
+
+    Args:
+        x_input (np.ndarray): Time series data
+        model (list, class): Trained model. It can be list of neural weigths or it can be fitted model class from imported library.
+        predicts (int, optional): Number of predicted values. Defaults to 7.
+
+    Returns:
+        np.ndarray: Array of predicted results
+    """
 
     x_input = x_input.ravel()
     predictions = []
